@@ -5,8 +5,10 @@ __all__ =\
 	'agile_innovative_blinkstick',
 	'lifx_light',
 	'magic_hue',
+	'nanoleaf_light',
 	'philips_hue',
 	'razer_chroma',
 	'thingm_blink',
+	'wiz_light',
 	'xiaomi_yeelight'
 ]
