@@ -11,7 +11,10 @@ def process(program : ArgumentParser, status : str) -> List[Dict[str, Any]]:
 	for consumer_name in args.consumer:
 		consumer = load_consumer(consumer_name)
 		consumer.init(program)
-		result.extend(consumer.run(status))
+		try:
+			result.extend(consumer.run(status))
+		except:
+			exit(wording.get('consumer_crash').format(consumer_name) + wording.get('exclamation_mark'))
 	return result
 
 
@@ -19,4 +22,4 @@ def load_consumer(consumer_name : str) -> Any:
 	try:
 		return importlib.import_module('chroma_feedback.consumer.' + consumer_name)
 	except ImportError:
-		exit(wording.get('consumer_no') + wording.get('exclamation_mark'))
+		exit(wording.get('consumer_no').format(consumer_name) + wording.get('exclamation_mark'))
