@@ -11,12 +11,12 @@ def init(program : ArgumentParser) -> None:
 	global ARGS
 
 	if not ARGS:
-		ip = None
+		ips = None
 
 		if not helper.has_argument('--xiaomi-yeelight-ip'):
-			ip = discover_ips()
-		if ip:
-			program.add_argument('--xiaomi-yeelight-ip', default = ip)
+			ips = discover_ips()
+		if ips:
+			program.add_argument('--xiaomi-yeelight-ip', default = ips)
 		else:
 			program.add_argument('--xiaomi-yeelight-ip', action = 'append', required = True)
 	ARGS = helper.get_first(program.parse_known_args())
@@ -35,7 +35,6 @@ def discover_ips() -> List[str]:
 	message =\
 	[
 		'M-SEARCH * HTTP/1.1',
-		'HOST: 239.255.255.250:1982',
 		'MAN: "ssdp:discover"',
 		'ST: wifi_bulb'
 	]
