@@ -1,6 +1,6 @@
 from typing import Any, Dict, List
+import platform
 import sys
-from requests import Response
 
 
 def get_producer_status(producer_result : List[Dict[str, Any]]) -> str:
@@ -10,9 +10,9 @@ def get_producer_status(producer_result : List[Dict[str, Any]]) -> str:
 
 	for producer in producer_result:
 		if producer['active'] is True:
-			if producer['status'] == 'process':
+			if producer['status'] == 'started':
 				if status not in ['errored', 'failed']:
-					status = 'process'
+					status = 'started'
 			if producer['status'] == 'errored':
 				if status != 'failed':
 					status = 'errored'
@@ -21,13 +21,6 @@ def get_producer_status(producer_result : List[Dict[str, Any]]) -> str:
 	return status
 
 
-def parse_json(response : Response) -> Any:
-	try:
-		return response.json()
-	except ValueError:
-		return None
-
-
 def to_lower_case(__string__ : Any) -> str:
 	return str(__string__).lower()
 
@@ -36,5 +29,13 @@ def has_argument(argument : str) -> bool:
 	return any(argument in argv for argv in sys.argv)
 
 
+def is_linux() -> bool:
+	return to_lower_case(platform.system()) == 'linux'
+
+
 def get_first(__list__ : Any) -> Any:
 	return next(iter(__list__), None)
+
+
+def get_last(__list__ : Any) -> Any:
+	return next(reversed(__list__), None)
