@@ -1,7 +1,6 @@
 from typing import Any, Dict, List
 from argparse import ArgumentParser
-import requests
-from chroma_feedback import helper
+from chroma_feedback import helper, request
 from .normalize import normalize_data
 
 ARGS = None
@@ -13,7 +12,7 @@ def init(program : ArgumentParser) -> None:
 	if not ARGS:
 		program.add_argument('--appveyor-host', default = 'https://ci.appveyor.com')
 		program.add_argument('--appveyor-slug', action = 'append')
-		program.add_argument('--appveyor-token')
+		program.add_argument('--appveyor-token', required = True)
 	ARGS = helper.get_first(program.parse_known_args())
 
 
@@ -32,18 +31,23 @@ def fetch(host : str, slug : str, token : str) -> List[Dict[str, Any]]:
 	result = []
 	response = None
 
-	if host and slug:
-		response = requests.get(host + '/api/projects/' + slug)
-	elif host and token:
-		response = requests.get(host + '/api/projects', headers =
+	if host and slug and token:
+		response = request.get(host + '/api/projects/' + slug, headers =
 		{
+			'Accept': 'application/json',
+			'Authorization': 'Bearer ' + token
+		})
+	elif host and token:
+		response = request.get(host + '/api/projects', headers =
+		{
+			'Accept': 'application/json',
 			'Authorization': 'Bearer ' + token
 		})
 
 	# process response
 
 	if response and response.status_code == 200:
-		data = helper.parse_json(response)
+		data = request.parse_json(response)
 
 		if 'project' and 'build' in data:
 			result.append(normalize_data(data['project'], data['build']))
