@@ -16,7 +16,7 @@ def normalize_status(status : str) -> str:
 	status = helper.to_lower_case(status)
 
 	if status in ['queued', 'running']:
-		return 'process'
+		return 'started'
 	if status == 'canceled':
 		return 'errored'
 	if status == 'failed':
