@@ -2,13 +2,13 @@ from typing import Any, Dict
 from chroma_feedback import helper
 
 
-def normalize_data(project : Dict[str, Any]) -> Dict[str, Any]:
+def normalize_data(build : Dict[str, Any]) -> Dict[str, Any]:
 	return\
 	{
 		'producer': 'circle',
-		'slug': project['username'] + '/' + project['reponame'],
+		'slug': build['project_slug'] + '/' + build['name'],
 		'active': True,
-		'status': normalize_status(project['status'])
+		'status': normalize_status(build['status'])
 	}
 
 
@@ -16,7 +16,7 @@ def normalize_status(status : str) -> str:
 	status = helper.to_lower_case(status)
 
 	if status in ['queued', 'running', 'scheduled']:
-		return 'process'
+		return 'started'
 	if status in ['canceled', 'no_tests']:
 		return 'errored'
 	if status == 'failed':
