@@ -6,7 +6,7 @@ def normalize_data(build : Dict[str, Any]) -> Dict[str, Any]:
 	return\
 	{
 		'producer': 'codeship',
-		'slug': str(build['project_id']),
+		'slug': build['slug'],
 		'active': True,
 		'status': normalize_status(build['status'])
 	}
@@ -16,7 +16,7 @@ def normalize_status(status : str) -> str:
 	status = helper.to_lower_case(status)
 
 	if status in ['initiated', 'testing', 'waiting']:
-		return 'process'
+		return 'started'
 	if status in ['error', 'blocked', 'ignored']:
 		return 'errored'
 	if status in ['failed', 'infrastructure_failure']:
