@@ -11,7 +11,10 @@ def process(program : ArgumentParser) -> List[Dict[str, Any]]:
 	for producer_name in args.producer:
 		producer = load_producer(producer_name)
 		producer.init(program)
-		result.extend(producer.run())
+		try:
+			result.extend(producer.run())
+		except:
+			exit(wording.get('producer_crash').format(producer_name) + wording.get('exclamation_mark'))
 	return result
 
 
@@ -19,4 +22,4 @@ def load_producer(producer_name : str) -> Any:
 	try:
 		return importlib.import_module('chroma_feedback.producer.' + producer_name)
 	except ImportError:
-		exit(wording.get('producer_no') + wording.get('exclamation_mark'))
+		exit(wording.get('producer_no').format(producer_name) + wording.get('exclamation_mark'))
